markuptools
===========

.. automodule:: abjad.tools.markuptools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.markuptools.Markup.Markup
      ~abjad.tools.markuptools.MarkupCommand.MarkupCommand
      ~abjad.tools.markuptools.MarkupInventory.MarkupInventory
      ~abjad.tools.markuptools.MusicGlyph.MusicGlyph

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.markuptools.combine_markup_commands.combine_markup_commands
      ~abjad.tools.markuptools.make_big_centered_page_number_markup.make_big_centered_page_number_markup
      ~abjad.tools.markuptools.make_blank_line_markup.make_blank_line_markup
      ~abjad.tools.markuptools.make_centered_title_markup.make_centered_title_markup
      ~abjad.tools.markuptools.make_vertically_adjusted_composer_markup.make_vertically_adjusted_composer_markup
